/*
 *  The Mana World
 *  Copyright 2004 The Mana World Development Team
 *
 *  This file is part of The Mana World.
 *
 *  The Mana World is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  any later version.
 *
 *  The Mana World is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with The Mana World; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 *  $Id: windowlistener.h 3606 2007-09-27 14:54:09Z b_lindeijer $
 */

#ifndef _TMW_WINDOW_LISTENER_H_
#define _TMW_WINDOW_LISTENER_H_

#include <guichan/widgets/window.hpp>
#include <guichan/event.hpp>

/**
 * An event that characterizes a window move or resize.
 *
 * \ingroup GUI
 */
class WindowEvent : public gcn::Event
{
    public:
        /**
         * Constructor.
         */
        WindowEvent(gcn::Window *source, int type):
            gcn::Event(source)
        {
            mType = type;
        }

        /**
         * Returns the event type.
         */
        int getType() const
        { return mType; }

        enum WindowEventType
        {
            WINDOW_MOVED,
            WINDOW_RESIZED
        };
};

/**
 * The listener that's notified when a window is moved or resized.
 *
 * \ingroup GUI
 */
class WindowListener
{
    public:
        /**
         * Virtual destructor.
         */
        virtual ~WindowListener() {}

        /**
         * Called whenever the window is moved.
         */
        virtual void windowMoved(const WindowEvent &) {}

        /**
         * Called whenever the window is resized.
         */
        virtual void windowResized(const WindowEvent &) {}
};

typedef std::list<WindowListener*> WindowListeners;

#endif
